@@ -29,7 +29,7 @@ def random_token(length=10):
 
 class BatchProcessor:
     def __init__(self, config):
-        self.worker_id = random_token(10)
+        self.worker_id = None
         self.config = config
         self.do_log = self.config.get("batch-log-logging", True)
         self.last_cleanup_time = datetime.datetime.now()
@@ -43,11 +43,17 @@ class BatchProcessor:
             logger.warning("Skipping database initialization")
         else:
             self.db = Database(self.config)
-        logger.info(f"Batch Processor {self.worker_id} instanciated")
+
+    def get_id(self):
+        if not self.worker_id:
+            self.worker_id = random_token(10)
+            logger.info(f"Batch Processor {self.worker_id} instanciated")
+        return self.worker_id
 
     def __del__(self):
-        logger.info(f"Batch Processor {self.worker_id} deleted")
-        self.worker_id = None
+        if self.worker_id:
+            logger.info(f"Batch Processor {self.worker_id} deleted")
+            self.worker_id = None
 
     def verify(self):
         modules = self.list_modules()
@@ -221,6 +227,7 @@ class BatchProcessor:
         # logger.info("SAFE EXECUTION STARTED!")
         failure = None
         result = None
+        watchdog = None
         try:
             # We cap runtime at TTL from which ever is set first; item ttl, param ttl or environment fallback value
             timeout = self.config.get("batch-default-ttl", 0)
@@ -266,7 +273,8 @@ class BatchProcessor:
         """
         Take ownership of one batch item and make sure it is properly executed and updated with status underway
         """
-        item = self.db.book_batch_item(self.db.PENDING, self.db.IN_PROGRESS, self.worker_id)
+        worker_id=self.get_id()
+        item = self.db.book_batch_item(self.db.PENDING, self.db.IN_PROGRESS, worker_id)
         if item:
             if self.do_log:
                 logger.info("Processing item:")
@@ -301,7 +309,8 @@ class BatchProcessor:
         Take ownership of one batch item and make sure it is properly executed and updated with status underway
         NOTE: Throttled version
         """
-        item = self.db.book_throttled_batch_item(self.db.PENDING, self.db.IN_PROGRESS, self.worker_id)
+        worker_id=self.get_id()
+        item = self.db.book_throttled_batch_item(self.db.PENDING, self.db.IN_PROGRESS, worker_id)
         if item:
             if self.do_log:
                 logger.info("Processing throttled item:")
@@ -381,6 +390,15 @@ class BatchProcessor:
     def delete_failed_jobs(self):
         self.db.delete_batch_items_with_status(self.db.FAILED)
 
+    def delete_pending_jobs(self):
+        self.db.delete_batch_items_with_status(self.db.PENDING)
+
+    def delete_in_progress_jobs(self):
+        self.db.delete_batch_items_with_status(self.db.IN_PROGRESS)
+
+    def delete_done_jobs(self):
+        self.db.delete_batch_items_with_status(self.db.DONE)
+
     def delete_all_jobs(self):
         self.db.delete_all()
 
